@@ -211,7 +211,7 @@ function makeMutClosure(arg0, arg1, dtor, f) {
     return real;
 }
 function __wbg_adapter_26(arg0, arg1, arg2) {
-    wasm._dyn_core__ops__function__FnMut__A____Output___R_as_wasm_bindgen__closure__WasmClosure___describe__invoke__hb819b4606ac1b551(arg0, arg1, addHeapObject(arg2));
+    wasm._dyn_core__ops__function__FnMut__A____Output___R_as_wasm_bindgen__closure__WasmClosure___describe__invoke__h4e37a62ffa13b731(arg0, arg1, addHeapObject(arg2));
 }
 
 /**
@@ -279,7 +279,7 @@ function passArray8ToWasm0(arg, malloc) {
     return ptr;
 }
 function __wbg_adapter_240(arg0, arg1, arg2, arg3) {
-    wasm.wasm_bindgen__convert__closures__invoke2_mut__h4d505d8c21e259a2(arg0, arg1, addHeapObject(arg2), addHeapObject(arg3));
+    wasm.wasm_bindgen__convert__closures__invoke2_mut__h4d59381e7733ca36(arg0, arg1, addHeapObject(arg2), addHeapObject(arg3));
 }
 
 /**
@@ -360,20 +360,20 @@ export class CameraConstraints {
     * Gets the minimum [`Resolution`].
     * # JS-WASM
     * This is exported as `get_MinResolution`.
-    * @returns {Resolution | undefined}
+    * @returns {JSResolution | undefined}
     */
     get MinResolution() {
         var ret = wasm.cameraconstraints_min_resolution(this.ptr);
-        return ret === 0 ? undefined : Resolution.__wrap(ret);
+        return ret === 0 ? undefined : JSResolution.__wrap(ret);
     }
     /**
     * Gets the minimum [`Resolution`].
     * # JS-WASM
     * This is exported as `set_MinResolution`.
-    * @param {Resolution} min_resolution
+    * @param {JSResolution} min_resolution
     */
     set MinResolution(min_resolution) {
-        _assertClass(min_resolution, Resolution);
+        _assertClass(min_resolution, JSResolution);
         var ptr0 = min_resolution.ptr;
         min_resolution.ptr = 0;
         wasm.cameraconstraints_set_min_resolution(this.ptr, ptr0);
@@ -382,11 +382,11 @@ export class CameraConstraints {
     * Gets the internal [`Resolution`]
     * # JS-WASM
     * This is exported as `get_Resolution`.
-    * @returns {Resolution}
+    * @returns {JSResolution}
     */
     get Resolution() {
         var ret = wasm.cameraconstraints_resolution(this.ptr);
-        return Resolution.__wrap(ret);
+        return JSResolution.__wrap(ret);
     }
     /**
     * Sets the internal [`Resolution`]
@@ -394,10 +394,10 @@ export class CameraConstraints {
     * [`apply_constraints()`](crate::js_camera::JSCameraConstraints::apply_constraints)
     * # JS-WASM
     * This is exported as `set_Resolution`.
-    * @param {Resolution} preferred_resolution
+    * @param {JSResolution} preferred_resolution
     */
     set Resolution(preferred_resolution) {
-        _assertClass(preferred_resolution, Resolution);
+        _assertClass(preferred_resolution, JSResolution);
         var ptr0 = preferred_resolution.ptr;
         preferred_resolution.ptr = 0;
         wasm.cameraconstraints_set_resolution(this.ptr, ptr0);
@@ -406,20 +406,20 @@ export class CameraConstraints {
     * Gets the maximum [`Resolution`].
     * # JS-WASM
     * This is exported as `get_MaxResolution`.
-    * @returns {Resolution | undefined}
+    * @returns {JSResolution | undefined}
     */
     get MaxResolution() {
         var ret = wasm.cameraconstraints_max_resolution(this.ptr);
-        return ret === 0 ? undefined : Resolution.__wrap(ret);
+        return ret === 0 ? undefined : JSResolution.__wrap(ret);
     }
     /**
     * Gets the maximum [`Resolution`].
     * # JS-WASM
     * This is exported as `set_MaxResolution`.
-    * @param {Resolution} max_resolution
+    * @param {JSResolution} max_resolution
     */
     set MaxResolution(max_resolution) {
-        _assertClass(max_resolution, Resolution);
+        _assertClass(max_resolution, JSResolution);
         var ptr0 = max_resolution.ptr;
         max_resolution.ptr = 0;
         wasm.cameraconstraints_set_max_resolution(this.ptr, ptr0);
@@ -882,12 +882,12 @@ export class CameraConstraintsBuilder {
     * Sets [`width`](https://developer.mozilla.org/en-US/docs/Web/API/MediaTrackConstraints/width) and [`height`](https://developer.mozilla.org/en-US/docs/Web/API/MediaTrackConstraints/height).
     * # JS-WASM
     * This is exported as `set_MinResolution`.
-    * @param {Resolution} min_resolution
+    * @param {JSResolution} min_resolution
     * @returns {CameraConstraintsBuilder}
     */
     MinResolution(min_resolution) {
         const ptr = this.__destroy_into_raw();
-        _assertClass(min_resolution, Resolution);
+        _assertClass(min_resolution, JSResolution);
         var ptr0 = min_resolution.ptr;
         min_resolution.ptr = 0;
         var ret = wasm.cameraconstraintsbuilder_MaxResolution(ptr, ptr0);
@@ -899,12 +899,12 @@ export class CameraConstraintsBuilder {
     * Sets [`width`](https://developer.mozilla.org/en-US/docs/Web/API/MediaTrackConstraints/width) and [`height`](https://developer.mozilla.org/en-US/docs/Web/API/MediaTrackConstraints/height).
     * # JS-WASM
     * This is exported as `set_Resolution`.
-    * @param {Resolution} new_resolution
+    * @param {JSResolution} new_resolution
     * @returns {CameraConstraintsBuilder}
     */
     Resolution(new_resolution) {
         const ptr = this.__destroy_into_raw();
-        _assertClass(new_resolution, Resolution);
+        _assertClass(new_resolution, JSResolution);
         var ptr0 = new_resolution.ptr;
         new_resolution.ptr = 0;
         var ret = wasm.cameraconstraintsbuilder_Resolution(ptr, ptr0);
@@ -916,12 +916,12 @@ export class CameraConstraintsBuilder {
     * Sets [`width`](https://developer.mozilla.org/en-US/docs/Web/API/MediaTrackConstraints/width) and [`height`](https://developer.mozilla.org/en-US/docs/Web/API/MediaTrackConstraints/height).
     * # JS-WASM
     * This is exported as `set_MaxResolution`.
-    * @param {Resolution} max_resolution
+    * @param {JSResolution} max_resolution
     * @returns {CameraConstraintsBuilder}
     */
     MaxResolution(max_resolution) {
         const ptr = this.__destroy_into_raw();
-        _assertClass(max_resolution, Resolution);
+        _assertClass(max_resolution, JSResolution);
         var ptr0 = max_resolution.ptr;
         max_resolution.ptr = 0;
         var ret = wasm.cameraconstraintsbuilder_MaxResolution(ptr, ptr0);
@@ -1178,12 +1178,12 @@ export class CameraConstraintsBuilder {
 * `description` amd `misc` may contain information that may differ from backend to backend. Refer to each backend for details.
 * `index` is a camera's index given to it by (usually) the OS usually in the order it is known to the system.
 * # JS-WASM
-* This is exported as a `CameraInfo`.
+* This is exported as a `JSCameraInfo`.
 */
-export class CameraInfo {
+export class JSCameraInfo {
 
     static __wrap(ptr) {
-        const obj = Object.create(CameraInfo.prototype);
+        const obj = Object.create(JSCameraInfo.prototype);
         obj.ptr = ptr;
 
         return obj;
@@ -1198,7 +1198,7 @@ export class CameraInfo {
 
     free() {
         const ptr = this.__destroy_into_raw();
-        wasm.__wbg_camerainfo_free(ptr);
+        wasm.__wbg_jscamerainfo_free(ptr);
     }
     /**
     * Create a new [`CameraInfo`].
@@ -1216,8 +1216,8 @@ export class CameraInfo {
         var len1 = WASM_VECTOR_LEN;
         var ptr2 = passStringToWasm0(misc, wasm.__wbindgen_malloc, wasm.__wbindgen_realloc);
         var len2 = WASM_VECTOR_LEN;
-        var ret = wasm.camerainfo_new(ptr0, len0, ptr1, len1, ptr2, len2, index);
-        return CameraInfo.__wrap(ret);
+        var ret = wasm.jscamerainfo_new(ptr0, len0, ptr1, len1, ptr2, len2, index);
+        return JSCameraInfo.__wrap(ret);
     }
     /**
     * Get a reference to the device info's human readable name.
@@ -1228,7 +1228,7 @@ export class CameraInfo {
     get HumanReadableName() {
         try {
             const retptr = wasm.__wbindgen_add_to_stack_pointer(-16);
-            wasm.camerainfo_human_name(retptr, this.ptr);
+            wasm.jscamerainfo_human_name(retptr, this.ptr);
             var r0 = getInt32Memory0()[retptr / 4 + 0];
             var r1 = getInt32Memory0()[retptr / 4 + 1];
             return getStringFromWasm0(r0, r1);
@@ -1246,7 +1246,7 @@ export class CameraInfo {
     set HumanReadableName(human_name) {
         var ptr0 = passStringToWasm0(human_name, wasm.__wbindgen_malloc, wasm.__wbindgen_realloc);
         var len0 = WASM_VECTOR_LEN;
-        wasm.camerainfo_set_human_name(this.ptr, ptr0, len0);
+        wasm.jscamerainfo_set_human_name(this.ptr, ptr0, len0);
     }
     /**
     * Get a reference to the device info's description.
@@ -1257,7 +1257,7 @@ export class CameraInfo {
     get Description() {
         try {
             const retptr = wasm.__wbindgen_add_to_stack_pointer(-16);
-            wasm.camerainfo_description(retptr, this.ptr);
+            wasm.jscamerainfo_description(retptr, this.ptr);
             var r0 = getInt32Memory0()[retptr / 4 + 0];
             var r1 = getInt32Memory0()[retptr / 4 + 1];
             return getStringFromWasm0(r0, r1);
@@ -1275,7 +1275,7 @@ export class CameraInfo {
     set Description(description) {
         var ptr0 = passStringToWasm0(description, wasm.__wbindgen_malloc, wasm.__wbindgen_realloc);
         var len0 = WASM_VECTOR_LEN;
-        wasm.camerainfo_set_description(this.ptr, ptr0, len0);
+        wasm.jscamerainfo_set_description(this.ptr, ptr0, len0);
     }
     /**
     * Get a reference to the device info's misc.
@@ -1286,7 +1286,7 @@ export class CameraInfo {
     get MiscString() {
         try {
             const retptr = wasm.__wbindgen_add_to_stack_pointer(-16);
-            wasm.camerainfo_misc(retptr, this.ptr);
+            wasm.jscamerainfo_misc(retptr, this.ptr);
             var r0 = getInt32Memory0()[retptr / 4 + 0];
             var r1 = getInt32Memory0()[retptr / 4 + 1];
             return getStringFromWasm0(r0, r1);
@@ -1304,7 +1304,7 @@ export class CameraInfo {
     set MiscString(misc) {
         var ptr0 = passStringToWasm0(misc, wasm.__wbindgen_malloc, wasm.__wbindgen_realloc);
         var len0 = WASM_VECTOR_LEN;
-        wasm.camerainfo_set_misc(this.ptr, ptr0, len0);
+        wasm.jscamerainfo_set_misc(this.ptr, ptr0, len0);
     }
     /**
     * Get a reference to the device info's index.
@@ -1313,7 +1313,7 @@ export class CameraInfo {
     * @returns {number}
     */
     get Index() {
-        var ret = wasm.camerainfo_index(this.ptr);
+        var ret = wasm.jscamerainfo_index(this.ptr);
         return ret >>> 0;
     }
     /**
@@ -1323,7 +1323,112 @@ export class CameraInfo {
     * @param {number} index
     */
     set Index(index) {
-        wasm.camerainfo_set_index(this.ptr, index);
+        wasm.jscamerainfo_set_index(this.ptr, index);
+    }
+}
+/**
+* Describes a Resolution.
+* This struct consists of a Width and a Height value (x,y). <br>
+* Note: the [`Ord`] implementation of this struct is flipped from highest to lowest.
+* # JS-WASM
+* This is exported as `JSResolution`
+*/
+export class JSResolution {
+
+    static __wrap(ptr) {
+        const obj = Object.create(JSResolution.prototype);
+        obj.ptr = ptr;
+
+        return obj;
+    }
+
+    __destroy_into_raw() {
+        const ptr = this.ptr;
+        this.ptr = 0;
+
+        return ptr;
+    }
+
+    free() {
+        const ptr = this.__destroy_into_raw();
+        wasm.__wbg_jsresolution_free(ptr);
+    }
+    /**
+    * @returns {number}
+    */
+    get width_x() {
+        var ret = wasm.__wbg_get_jsresolution_width_x(this.ptr);
+        return ret >>> 0;
+    }
+    /**
+    * @param {number} arg0
+    */
+    set width_x(arg0) {
+        wasm.__wbg_set_jsresolution_width_x(this.ptr, arg0);
+    }
+    /**
+    * @returns {number}
+    */
+    get height_y() {
+        var ret = wasm.__wbg_get_jsresolution_height_y(this.ptr);
+        return ret >>> 0;
+    }
+    /**
+    * @param {number} arg0
+    */
+    set height_y(arg0) {
+        wasm.__wbg_set_jsresolution_height_y(this.ptr, arg0);
+    }
+    /**
+    * Create a new resolution from 2 image size coordinates.
+    * # JS-WASM
+    * This is exported as a constructor for [`Resolution`].
+    * @param {number} x
+    * @param {number} y
+    */
+    constructor(x, y) {
+        var ret = wasm.jsresolution_new(x, y);
+        return JSResolution.__wrap(ret);
+    }
+    /**
+    * Get the width of Resolution
+    * # JS-WASM
+    * This is exported as `get_Width`.
+    * @returns {number}
+    */
+    get Width() {
+        const ptr = this.__destroy_into_raw();
+        var ret = wasm.jsresolution_width(ptr);
+        return ret >>> 0;
+    }
+    /**
+    * Get the height of Resolution
+    * # JS-WASM
+    * This is exported as `get_Height`.
+    * @returns {number}
+    */
+    get Height() {
+        const ptr = this.__destroy_into_raw();
+        var ret = wasm.jsresolution_height(ptr);
+        return ret >>> 0;
+    }
+    /**
+    * Get the x (width) of Resolution
+    * @returns {number}
+    */
+    x() {
+        const ptr = this.__destroy_into_raw();
+        var ret = wasm.jsresolution_width(ptr);
+        return ret >>> 0;
+    }
+    /**
+    * Get the y (height) of Resolution
+    * @returns {number}
+    */
+    y() {
+        const ptr = this.__destroy_into_raw();
+        var ret = wasm.jsresolution_height(ptr);
+        return ret >>> 0;
     }
 }
 /**
@@ -1399,11 +1504,11 @@ export class NokhwaCamera {
     * Note: This value is only updated after you call [`measure_resolution`](crate::js_camera::JSCamera::measure_resolution)
     * # JS-WASM
     * This is exported as `get_Resolution`.
-    * @returns {Resolution}
+    * @returns {JSResolution}
     */
     get Resolution() {
         var ret = wasm.nokhwacamera_resolution(this.ptr);
-        return Resolution.__wrap(ret);
+        return JSResolution.__wrap(ret);
     }
     /**
     * Measures the [`Resolution`] of the internal stream. You usually do not need to call this.
@@ -1549,111 +1654,6 @@ export class NokhwaCamera {
         wasm.nokhwacamera_stopAll(this.ptr);
     }
 }
-/**
-* Describes a Resolution.
-* This struct consists of a Width and a Height value (x,y). <br>
-* Note: the [`Ord`] implementation of this struct is flipped from highest to lowest.
-* # JS-WASM
-* This is exported as `Resolution`
-*/
-export class Resolution {
-
-    static __wrap(ptr) {
-        const obj = Object.create(Resolution.prototype);
-        obj.ptr = ptr;
-
-        return obj;
-    }
-
-    __destroy_into_raw() {
-        const ptr = this.ptr;
-        this.ptr = 0;
-
-        return ptr;
-    }
-
-    free() {
-        const ptr = this.__destroy_into_raw();
-        wasm.__wbg_resolution_free(ptr);
-    }
-    /**
-    * @returns {number}
-    */
-    get width_x() {
-        var ret = wasm.__wbg_get_resolution_width_x(this.ptr);
-        return ret >>> 0;
-    }
-    /**
-    * @param {number} arg0
-    */
-    set width_x(arg0) {
-        wasm.__wbg_set_resolution_width_x(this.ptr, arg0);
-    }
-    /**
-    * @returns {number}
-    */
-    get height_y() {
-        var ret = wasm.__wbg_get_resolution_height_y(this.ptr);
-        return ret >>> 0;
-    }
-    /**
-    * @param {number} arg0
-    */
-    set height_y(arg0) {
-        wasm.__wbg_set_resolution_height_y(this.ptr, arg0);
-    }
-    /**
-    * Create a new resolution from 2 image size coordinates.
-    * # JS-WASM
-    * This is exported as a constructor for [`Resolution`].
-    * @param {number} x
-    * @param {number} y
-    */
-    constructor(x, y) {
-        var ret = wasm.resolution_new(x, y);
-        return Resolution.__wrap(ret);
-    }
-    /**
-    * Get the width of Resolution
-    * # JS-WASM
-    * This is exported as `get_Width`.
-    * @returns {number}
-    */
-    get Width() {
-        const ptr = this.__destroy_into_raw();
-        var ret = wasm.resolution_width(ptr);
-        return ret >>> 0;
-    }
-    /**
-    * Get the height of Resolution
-    * # JS-WASM
-    * This is exported as `get_Height`.
-    * @returns {number}
-    */
-    get Height() {
-        const ptr = this.__destroy_into_raw();
-        var ret = wasm.resolution_height(ptr);
-        return ret >>> 0;
-    }
-    /**
-    * Get the x (width) of Resolution
-    * @returns {number}
-    */
-    x() {
-        const ptr = this.__destroy_into_raw();
-        var ret = wasm.resolution_width(ptr);
-        return ret >>> 0;
-    }
-    /**
-    * Get the y (height) of Resolution
-    * @returns {number}
-    */
-    y() {
-        const ptr = this.__destroy_into_raw();
-        var ret = wasm.resolution_height(ptr);
-        return ret >>> 0;
-    }
-}
 
 async function load(module, imports) {
     if (typeof Response === 'function' && module instanceof Response) {
@@ -1719,6 +1719,10 @@ async function init(input) {
         var ret = getObject(arg0) === getObject(arg1);
         return ret;
     };
+    imports.wbg.__wbg_jscamerainfo_new = function(arg0) {
+        var ret = JSCameraInfo.__wrap(arg0);
+        return addHeapObject(ret);
+    };
     imports.wbg.__wbindgen_cb_drop = function(arg0) {
         const obj = takeObject(arg0).original;
         if (obj.cnt-- == 1) {
@@ -1728,171 +1732,167 @@ async function init(input) {
         var ret = false;
         return ret;
     };
-    imports.wbg.__wbg_camerainfo_new = function(arg0) {
-        var ret = CameraInfo.__wrap(arg0);
-        return addHeapObject(ret);
-    };
-    imports.wbg.__wbg_instanceof_Window_11e25482011fc506 = function(arg0) {
+    imports.wbg.__wbg_instanceof_Window_fac4f1f8e3c61c1f = function(arg0) {
         var ret = getObject(arg0) instanceof Window;
         return ret;
     };
-    imports.wbg.__wbg_document_5aff8cd83ef968f5 = function(arg0) {
+    imports.wbg.__wbg_document_29fb71d7cea23553 = function(arg0) {
         var ret = getObject(arg0).document;
         return isLikeNone(ret) ? 0 : addHeapObject(ret);
     };
-    imports.wbg.__wbg_navigator_5c90643c2a2b6cda = function(arg0) {
+    imports.wbg.__wbg_navigator_f92994fb618b3c03 = function(arg0) {
         var ret = getObject(arg0).navigator;
         return addHeapObject(ret);
     };
-    imports.wbg.__wbg_body_525168d9e773c3f8 = function(arg0) {
+    imports.wbg.__wbg_body_3f92bb47323529c7 = function(arg0) {
         var ret = getObject(arg0).body;
         return isLikeNone(ret) ? 0 : addHeapObject(ret);
     };
-    imports.wbg.__wbg_createElement_ac65a6ce60c4812c = function() { return handleError(function (arg0, arg1, arg2) {
+    imports.wbg.__wbg_createElement_8a4eea3a05d8804d = function() { return handleError(function (arg0, arg1, arg2) {
         var ret = getObject(arg0).createElement(getStringFromWasm0(arg1, arg2));
         return addHeapObject(ret);
     }, arguments) };
-    imports.wbg.__wbg_getElementById_b180ea4ada06a837 = function(arg0, arg1, arg2) {
+    imports.wbg.__wbg_getElementById_8ef24477d541ac87 = function(arg0, arg1, arg2) {
         var ret = getObject(arg0).getElementById(getStringFromWasm0(arg1, arg2));
         return isLikeNone(ret) ? 0 : addHeapObject(ret);
     };
-    imports.wbg.__wbg_clone_907d18181dd9fdec = function(arg0) {
+    imports.wbg.__wbg_clone_d5865137805e11f0 = function(arg0) {
         var ret = getObject(arg0).clone();
         return addHeapObject(ret);
     };
-    imports.wbg.__wbg_getTracks_453d59960c6b0998 = function(arg0) {
+    imports.wbg.__wbg_getTracks_b3a13f4ac20b87c3 = function(arg0) {
         var ret = getObject(arg0).getTracks();
         return addHeapObject(ret);
     };
-    imports.wbg.__wbg_getVideoTracks_c67b7117e61e6768 = function(arg0) {
+    imports.wbg.__wbg_getVideoTracks_0756ff6c988b94ca = function(arg0) {
         var ret = getObject(arg0).getVideoTracks();
         return addHeapObject(ret);
     };
-    imports.wbg.__wbg_appendChild_6ed236bb79c198df = function() { return handleError(function (arg0, arg1) {
+    imports.wbg.__wbg_appendChild_f52907370cfda116 = function() { return handleError(function (arg0, arg1) {
         var ret = getObject(arg0).appendChild(getObject(arg1));
         return addHeapObject(ret);
     }, arguments) };
-    imports.wbg.__wbg_removeChild_f633f19eb895b696 = function() { return handleError(function (arg0, arg1) {
+    imports.wbg.__wbg_removeChild_a5b181d3ef9e42e8 = function() { return handleError(function (arg0, arg1) {
         var ret = getObject(arg0).removeChild(getObject(arg1));
         return addHeapObject(ret);
     }, arguments) };
-    imports.wbg.__wbg_instanceof_MediaDeviceInfo_cdf31c28bb9459ae = function(arg0) {
+    imports.wbg.__wbg_instanceof_MediaDeviceInfo_40c073339e661eaf = function(arg0) {
         var ret = getObject(arg0) instanceof MediaDeviceInfo;
         return ret;
     };
-    imports.wbg.__wbg_deviceId_52909f91167fa503 = function(arg0, arg1) {
+    imports.wbg.__wbg_deviceId_e0d2b92a301e4559 = function(arg0, arg1) {
         var ret = getObject(arg1).deviceId;
         var ptr0 = passStringToWasm0(ret, wasm.__wbindgen_malloc, wasm.__wbindgen_realloc);
         var len0 = WASM_VECTOR_LEN;
         getInt32Memory0()[arg0 / 4 + 1] = len0;
         getInt32Memory0()[arg0 / 4 + 0] = ptr0;
     };
-    imports.wbg.__wbg_kind_7f46301e232da76a = function(arg0) {
+    imports.wbg.__wbg_kind_b07d33c74c81012a = function(arg0) {
         var ret = getObject(arg0).kind;
         return addHeapObject(ret);
     };
-    imports.wbg.__wbg_groupId_f6b7aa74f6b78e09 = function(arg0, arg1) {
+    imports.wbg.__wbg_groupId_014e664b0dd834e2 = function(arg0, arg1) {
         var ret = getObject(arg1).groupId;
         var ptr0 = passStringToWasm0(ret, wasm.__wbindgen_malloc, wasm.__wbindgen_realloc);
         var len0 = WASM_VECTOR_LEN;
         getInt32Memory0()[arg0 / 4 + 1] = len0;
         getInt32Memory0()[arg0 / 4 + 0] = ptr0;
     };
-    imports.wbg.__wbg_enumerateDevices_fe5818b3c5c78822 = function() { return handleError(function (arg0) {
+    imports.wbg.__wbg_enumerateDevices_9072d82313d22f95 = function() { return handleError(function (arg0) {
         var ret = getObject(arg0).enumerateDevices();
         return addHeapObject(ret);
     }, arguments) };
-    imports.wbg.__wbg_getSupportedConstraints_fa3e91cb9dd6da4c = function(arg0) {
+    imports.wbg.__wbg_getSupportedConstraints_64e60b65d4d85a84 = function(arg0) {
         var ret = getObject(arg0).getSupportedConstraints();
         return addHeapObject(ret);
     };
-    imports.wbg.__wbg_getUserMedia_c7f57dc542dcd8c6 = function() { return handleError(function (arg0, arg1) {
+    imports.wbg.__wbg_getUserMedia_e6eae49c6d7ada49 = function() { return handleError(function (arg0, arg1) {
         var ret = getObject(arg0).getUserMedia(getObject(arg1));
         return addHeapObject(ret);
     }, arguments) };
-    imports.wbg.__wbg_setid_cea8de140a58c4f1 = function(arg0, arg1, arg2) {
+    imports.wbg.__wbg_setid_53f28f9ba86fa773 = function(arg0, arg1, arg2) {
         getObject(arg0).id = getStringFromWasm0(arg1, arg2);
     };
-    imports.wbg.__wbg_setAttribute_27ca65e30a1c3c4a = function() { return handleError(function (arg0, arg1, arg2, arg3, arg4) {
+    imports.wbg.__wbg_setAttribute_936a229ff5ccc5c9 = function() { return handleError(function (arg0, arg1, arg2, arg3, arg4) {
         getObject(arg0).setAttribute(getStringFromWasm0(arg1, arg2), getStringFromWasm0(arg3, arg4));
     }, arguments) };
-    imports.wbg.__wbg_log_9a99fb1af846153b = function(arg0) {
+    imports.wbg.__wbg_log_4989d5b00a0cc297 = function(arg0) {
         console.log(getObject(arg0));
     };
-    imports.wbg.__wbg_sethidden_4e6127e185ecf2df = function(arg0, arg1) {
+    imports.wbg.__wbg_sethidden_ee4d19afe8cd207b = function(arg0, arg1) {
         getObject(arg0).hidden = arg1 !== 0;
     };
-    imports.wbg.__wbg_instanceof_CanvasRenderingContext2d_779e79c4121aa91b = function(arg0) {
+    imports.wbg.__wbg_instanceof_CanvasRenderingContext2d_c3096464126a8635 = function(arg0) {
         var ret = getObject(arg0) instanceof CanvasRenderingContext2D;
         return ret;
     };
-    imports.wbg.__wbg_drawImage_1edb91863f89d75c = function() { return handleError(function (arg0, arg1, arg2, arg3, arg4, arg5) {
+    imports.wbg.__wbg_drawImage_05c14fd60955efe6 = function() { return handleError(function (arg0, arg1, arg2, arg3, arg4, arg5) {
         getObject(arg0).drawImage(getObject(arg1), arg2, arg3, arg4, arg5);
     }, arguments) };
-    imports.wbg.__wbg_drawImage_13e48c4e7b9bcf28 = function() { return handleError(function (arg0, arg1, arg2, arg3, arg4, arg5) {
+    imports.wbg.__wbg_drawImage_369314fa18826781 = function() { return handleError(function (arg0, arg1, arg2, arg3, arg4, arg5) {
         getObject(arg0).drawImage(getObject(arg1), arg2, arg3, arg4, arg5);
     }, arguments) };
-    imports.wbg.__wbg_getImageData_b5842f1d6ce40388 = function() { return handleError(function (arg0, arg1, arg2, arg3, arg4) {
+    imports.wbg.__wbg_getImageData_95d4ea9a3956ff99 = function() { return handleError(function (arg0, arg1, arg2, arg3, arg4) {
         var ret = getObject(arg0).getImageData(arg1, arg2, arg3, arg4);
         return addHeapObject(ret);
     }, arguments) };
-    imports.wbg.__wbg_setsrcObject_340bcd93145a797b = function(arg0, arg1) {
+    imports.wbg.__wbg_setsrcObject_84ea10d6459b8777 = function(arg0, arg1) {
         getObject(arg0).srcObject = getObject(arg1);
     };
-    imports.wbg.__wbg_mediaDevices_b3973ebf40387065 = function() { return handleError(function (arg0) {
+    imports.wbg.__wbg_mediaDevices_95a03876999ceedf = function() { return handleError(function (arg0) {
         var ret = getObject(arg0).mediaDevices;
         return addHeapObject(ret);
     }, arguments) };
-    imports.wbg.__wbg_instanceof_HtmlCanvasElement_fd3cbbe3906d7792 = function(arg0) {
+    imports.wbg.__wbg_instanceof_HtmlCanvasElement_f6c37daa8caa628a = function(arg0) {
         var ret = getObject(arg0) instanceof HTMLCanvasElement;
         return ret;
     };
-    imports.wbg.__wbg_setwidth_f3c88eb520ba8d47 = function(arg0, arg1) {
+    imports.wbg.__wbg_setwidth_6ffbc02dcd566284 = function(arg0, arg1) {
         getObject(arg0).width = arg1 >>> 0;
     };
-    imports.wbg.__wbg_setheight_5a1abba41e35c42a = function(arg0, arg1) {
+    imports.wbg.__wbg_setheight_dade0779787da2d7 = function(arg0, arg1) {
         getObject(arg0).height = arg1 >>> 0;
     };
-    imports.wbg.__wbg_getContext_813df131fcbd6e91 = function() { return handleError(function (arg0, arg1, arg2) {
+    imports.wbg.__wbg_getContext_591a34067d6e74f2 = function() { return handleError(function (arg0, arg1, arg2) {
         var ret = getObject(arg0).getContext(getStringFromWasm0(arg1, arg2));
         return isLikeNone(ret) ? 0 : addHeapObject(ret);
     }, arguments) };
-    imports.wbg.__wbg_toDataURL_fa0138af5cf03aa2 = function() { return handleError(function (arg0, arg1, arg2, arg3, arg4) {
+    imports.wbg.__wbg_toDataURL_506af7317355ef50 = function() { return handleError(function (arg0, arg1, arg2, arg3, arg4) {
         var ret = getObject(arg1).toDataURL(getStringFromWasm0(arg2, arg3), getObject(arg4));
         var ptr0 = passStringToWasm0(ret, wasm.__wbindgen_malloc, wasm.__wbindgen_realloc);
         var len0 = WASM_VECTOR_LEN;
         getInt32Memory0()[arg0 / 4 + 1] = len0;
         getInt32Memory0()[arg0 / 4 + 0] = ptr0;
     }, arguments) };
-    imports.wbg.__wbg_data_315524ada7b563f4 = function(arg0, arg1) {
+    imports.wbg.__wbg_data_3b5132cf708f3fa5 = function(arg0, arg1) {
         var ret = getObject(arg1).data;
         var ptr0 = passArray8ToWasm0(ret, wasm.__wbindgen_malloc);
         var len0 = WASM_VECTOR_LEN;
         getInt32Memory0()[arg0 / 4 + 1] = len0;
         getInt32Memory0()[arg0 / 4 + 0] = ptr0;
     };
-    imports.wbg.__wbg_instanceof_HtmlVideoElement_acfaf2202e3e0d29 = function(arg0) {
+    imports.wbg.__wbg_instanceof_HtmlVideoElement_fc0a10eaf320d2aa = function(arg0) {
         var ret = getObject(arg0) instanceof HTMLVideoElement;
         return ret;
     };
-    imports.wbg.__wbg_setwidth_4006f4b33b15224b = function(arg0, arg1) {
+    imports.wbg.__wbg_setwidth_2f7483815ec07834 = function(arg0, arg1) {
         getObject(arg0).width = arg1 >>> 0;
     };
-    imports.wbg.__wbg_setheight_6a5930569b122df0 = function(arg0, arg1) {
+    imports.wbg.__wbg_setheight_2b2cb0447984d19f = function(arg0, arg1) {
         getObject(arg0).height = arg1 >>> 0;
     };
-    imports.wbg.__wbg_label_21de6784a6632e75 = function(arg0, arg1) {
+    imports.wbg.__wbg_label_b3c3caf2db14bc2f = function(arg0, arg1) {
         var ret = getObject(arg1).label;
         var ptr0 = passStringToWasm0(ret, wasm.__wbindgen_malloc, wasm.__wbindgen_realloc);
         var len0 = WASM_VECTOR_LEN;
         getInt32Memory0()[arg0 / 4 + 1] = len0;
         getInt32Memory0()[arg0 / 4 + 0] = ptr0;
     };
-    imports.wbg.__wbg_getSettings_654b758d29aaf3ad = function(arg0) {
+    imports.wbg.__wbg_getSettings_9ae79ab256250296 = function(arg0) {
         var ret = getObject(arg0).getSettings();
         return addHeapObject(ret);
     };
-    imports.wbg.__wbg_stop_f96817735e68ad3d = function(arg0) {
+    imports.wbg.__wbg_stop_b2e5a05e9a386ba1 = function(arg0) {
         getObject(arg0).stop();
     };
     imports.wbg.__wbg_get_73c087db0a496c21 = function(arg0, arg1) {
@@ -2032,8 +2032,8 @@ async function init(input) {
     imports.wbg.__wbindgen_rethrow = function(arg0) {
         throw takeObject(arg0);
     };
-    imports.wbg.__wbindgen_closure_wrapper761 = function(arg0, arg1, arg2) {
-        var ret = makeMutClosure(arg0, arg1, 64, __wbg_adapter_26);
+    imports.wbg.__wbindgen_closure_wrapper767 = function(arg0, arg1, arg2) {
+        var ret = makeMutClosure(arg0, arg1, 65, __wbg_adapter_26);
         return addHeapObject(ret);
     };
 
